Changelog
===============================================================================

All notable changes to this project will be documented in this file.

The format is based on 
[Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to 
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).


[1.0.0] - 2019-04-13
----------------------------------------

Initial version.


### Added

- Continued fractions of `int`, `float`,
  `fractions.Fraction` and rational numbers expressed as tuples of 2 integers
  `(numerator, denominator)`
- Convergents of the same data types
- Evaluate finite continued fraction into a value
- Arithmetical expression as string of a continued fraction
